coef.pmrm_fit: Treatment effect parameters

View source: R/coef.R

coef.pmrm_fitR Documentation

Treatment effect parameters

Description

Extract the theta parameter from a progression model for repeated measures.

Usage

## S3 method for class 'pmrm_fit'
coef(object, ...)

Arguments

object

A fitted model object of class "pmrm_fit".

...

Not used.

Details

See vignette("models", package = "pmrm") for details.

Value

For proportional models, a named vector of theta estimates with one element for each active study arm. For non-proportional models, a named matrix of theta with one row for each active study arm and one column for each post-baseline scheduled visit. Elements, rows, and columns are named with arm/visit names as appropriate.

See Also

Other estimates: VarCorr.pmrm_fit(), pmrm_marginals(), tidy.pmrm_fit(), vcov.pmrm_fit()

Examples

  set.seed(0L)
  simulation <- pmrm_simulate_decline_proportional(
    visit_times = seq_len(5L) - 1,
    gamma = c(1, 2)
  )
  fit <- pmrm_model_decline_proportional(
    data = simulation,
    outcome = "y",
    time = "t",
    patient = "patient",
    visit = "visit",
    arm = "arm",
    covariates = ~ w_1 + w_2
  )
  coef(fit)

pmrm documentation built on March 12, 2026, 5:07 p.m.