glance.pmrm_fit: Glance at a PMRM.

View source: R/glance.R

glance.pmrm_fitR Documentation

Glance at a PMRM.

Description

Return a one-row tibble of model comparison metrics for a fitted PMRM.

Usage

## S3 method for class 'pmrm_fit'
glance(x, ...)

Arguments

x

A fitted model x of class "pmrm_fit".

...

Not used.

Value

A tibble with one row and columns with the following columns:

  • model: "decline" or "slowing".

  • parameterization: "proportional" or "nonproportional".

  • n_observations: number of non-missing observations in the data.

  • n_parameters: number of true model parameters.

  • log_likelihood: maximized log likelihood of the model fit.

  • deviance: deviance of the fitted model, defined here as -2 * log_likelihood.

  • aic: Akaike information criterion.

  • bic: Bayesian information criterion.

This format is designed for easy comparison of multiple fitted models.

See Also

Other model comparison: AIC.pmrm_fit(), BIC.pmrm_fit(), confint.pmrm_fit(), deviance.pmrm_fit(), logLik.pmrm_fit(), summary.pmrm_fit()

Examples

  set.seed(0L)
  simulation <- pmrm_simulate_decline_proportional(
    visit_times = seq_len(5L) - 1,
    gamma = c(1, 2)
  )
  fit <- pmrm_model_decline_proportional(
    data = simulation,
    outcome = "y",
    time = "t",
    patient = "patient",
    visit = "visit",
    arm = "arm",
    covariates = ~ w_1 + w_2
  )
  glance(fit)

pmrm documentation built on March 12, 2026, 5:07 p.m.