| summary.pmrm_fit | R Documentation |
Summarize a progression model for repeated measures (PMRM).
## S3 method for class 'pmrm_fit'
summary(object, ...)
object |
A fitted model object of class |
... |
Not used. |
A tibble with one row and columns with the following columns:
model: "decline" or "slowing".
parameterization: "proportional" or "nonproportional".
n_observations: number of non-missing observations in the data.
n_parameters: number of true model parameters.
log_likelihood: maximized log likelihood of the model fit.
deviance: deviance of the fitted model, defined here as
-2 * log_likelihood.
aic: Akaike information criterion.
bic: Bayesian information criterion.
This format is designed for easy comparison of multiple fitted models.
Other model comparison:
AIC.pmrm_fit(),
BIC.pmrm_fit(),
confint.pmrm_fit(),
deviance.pmrm_fit(),
glance.pmrm_fit(),
logLik.pmrm_fit()
set.seed(0L)
simulation <- pmrm_simulate_decline_proportional(
visit_times = seq_len(5L) - 1,
gamma = c(1, 2)
)
fit <- pmrm_model_decline_proportional(
data = simulation,
outcome = "y",
time = "t",
patient = "patient",
visit = "visit",
arm = "arm",
covariates = ~ w_1 + w_2
)
summary(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.