tidy.pmrm_fit: Tidy a fitted PMRM.

View source: R/tidy.R

tidy.pmrm_fitR Documentation

Tidy a fitted PMRM.

Description

Return tidy parameter summaries of a progression model for repeated measures (PMRM).

Usage

## S3 method for class 'pmrm_fit'
tidy(x, ...)

Arguments

x

A fitted progression model for repeated measures (PMRM).

...

Not used.

Value

A tidy tibble with one row for each treatment effect model parameter (theta) and columns with the parameter name (study arm and/or visit it corresponds to), estimate, and standard error. This format aligns with the tidy() method of similar fitted models in R.

See Also

Other estimates: VarCorr.pmrm_fit(), coef.pmrm_fit(), pmrm_marginals(), vcov.pmrm_fit()

Examples

  set.seed(0L)
  simulation <- pmrm_simulate_decline_proportional(
    visit_times = seq_len(5L) - 1,
    gamma = c(1, 2)
  )
  fit <- pmrm_model_decline_proportional(
    data = simulation,
    outcome = "y",
    time = "t",
    patient = "patient",
    visit = "visit",
    arm = "arm",
    covariates = ~ w_1 + w_2
  )
  tidy(fit)

pmrm documentation built on March 12, 2026, 5:07 p.m.