vcov.pmrm_fit: Treatment effect parameter covariance matrix

View source: R/vcov.R

vcov.pmrm_fitR Documentation

Treatment effect parameter covariance matrix

Description

Extract the covariance matrix of the treatment effect parameters of a progression model for repeated measures.

Usage

## S3 method for class 'pmrm_fit'
vcov(object, ...)

Arguments

object

A fitted model object of class "pmrm_fit".

...

Not used.

Value

A matrix with covariance of each pair of theta parameters. Rows and columns are labeled (by just study arm for proportional models, arm and visit for non-proportional models.)

See Also

Other estimates: VarCorr.pmrm_fit(), coef.pmrm_fit(), pmrm_marginals(), tidy.pmrm_fit()

Examples

  set.seed(0L)
  simulation <- pmrm_simulate_decline_proportional(
    visit_times = seq_len(5L) - 1,
    gamma = c(1, 2)
  )
  fit <- pmrm_model_decline_proportional(
    data = simulation,
    outcome = "y",
    time = "t",
    patient = "patient",
    visit = "visit",
    arm = "arm",
    covariates = ~ w_1 + w_2
  )
  vcov(fit)

pmrm documentation built on March 12, 2026, 5:07 p.m.