View source: R/pmrm_estimates.R
| pmrm_estimates | R Documentation |
Report parameter estimates and confidence intervals for a progression model for repeated measures (PMRM).
pmrm_estimates(
fit,
parameter = c("theta", "beta", "alpha", "gamma", "sigma", "phi", "rho", "Sigma",
"Lambda"),
confidence = 0.95
)
fit |
A fitted model object of class |
parameter |
Character string, name of the type of model
parameter to summarize. Must be one of |
confidence |
Numeric between 0 and 1, the confidence level to use in 2-sided normal confidence intervals. |
A tibble with one row for each scalar element of the
selected model parameter and columns with estimates,
standard errors, lower and upper bounds of two-sided
normal confidence intervals, and indexing variables.
If applicable, the indexing variables are arm and/or visit
to indicate the study arm and study visit.
If there is no obvious indexing factor in the data,
then a generic integer index column is used.
For covariance matrices, elements are identified with the
visit_row and visit_column columns.
beta is not a true parameter.
Instead, it is a function of theta and fixed at zero
for the control arm and at baseline.
At these marginals,
the standard errors and confidence intervals for beta are NA_real_.
set.seed(0L)
simulation <- pmrm_simulate_decline_nonproportional(
visit_times = seq_len(5L) - 1,
gamma = c(1, 2)
)
fit <- pmrm_model_decline_nonproportional(
data = simulation,
outcome = "y",
time = "t",
patient = "patient",
visit = "visit",
arm = "arm",
covariates = ~ w_1 + w_2
)
pmrm_estimates(fit, parameter = "beta")
pmrm_estimates(fit, parameter = "alpha")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.