| tidy.pmrm_fit | R Documentation |
Return tidy parameter summaries of a progression model for repeated measures (PMRM).
## S3 method for class 'pmrm_fit'
tidy(x, ...)
x |
A fitted progression model for repeated measures (PMRM). |
... |
Not used. |
A tidy tibble with one row for each treatment effect
model parameter (theta) and columns with the parameter name
(study arm and/or visit it corresponds to), estimate,
and standard error. This format aligns with the tidy()
method of similar fitted models in R.
Other estimates:
VarCorr.pmrm_fit(),
coef.pmrm_fit(),
pmrm_marginals(),
vcov.pmrm_fit()
set.seed(0L)
simulation <- pmrm_simulate_decline_proportional(
visit_times = seq_len(5L) - 1,
gamma = c(1, 2)
)
fit <- pmrm_model_decline_proportional(
data = simulation,
outcome = "y",
time = "t",
patient = "patient",
visit = "visit",
arm = "arm",
covariates = ~ w_1 + w_2
)
tidy(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.