| vcov.pmrm_fit | R Documentation |
Extract the covariance matrix of the treatment effect parameters of a progression model for repeated measures.
## S3 method for class 'pmrm_fit'
vcov(object, ...)
object |
A fitted model object of class |
... |
Not used. |
A matrix with covariance of each pair of theta parameters.
Rows and columns are labeled (by just study arm for proportional models,
arm and visit for non-proportional models.)
Other estimates:
VarCorr.pmrm_fit(),
coef.pmrm_fit(),
pmrm_marginals(),
tidy.pmrm_fit()
set.seed(0L)
simulation <- pmrm_simulate_decline_proportional(
visit_times = seq_len(5L) - 1,
gamma = c(1, 2)
)
fit <- pmrm_model_decline_proportional(
data = simulation,
outcome = "y",
time = "t",
patient = "patient",
visit = "visit",
arm = "arm",
covariates = ~ w_1 + w_2
)
vcov(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.